@@ -3,7 +3,7 @@ utils module (imdb package).
 
 This module provides basic utilities for the imdb package.
 
-Copyright 2004-2009 Davide Alberani <da@erlug.linux.it>
+Copyright 2004-2010 Davide Alberani <da@erlug.linux.it>
                2009 H. Turgut Uyar <uyar@tekir.org>
 
 This program is free software; you can redistribute it and/or modify
@@ -644,6 +644,14 @@ def cmpMovies(m1, m2):
     m2i = m2.get('imdbIndex', _last)
     if m1i > m2i: return -1
     if m1i < m2i: return 1
+    m1id = getattr(m1, 'movieID', None)
+    # Introduce this check even for other comparisons functions?
+    # XXX: is it safe to check without knowning the data access system?
+    #      probably not a great idea.  Check for 'kind', instead?
+    if m1id is not None:
+        m2id = getattr(m2, 'movieID', None)
+        if m1id > m2id: return -1
+        elif m1id < m2id: return 1
     return 0
 
 
@@ -1024,7 +1032,7 @@ _xmlHead = u"""<?xml version="1.0"?>
 
 """
 _xmlHead = _xmlHead.replace('{VERSION}',
-            VERSION.replace('.', '').split('svn')[0])
+            VERSION.replace('.', '').split('dev')[0])
 
 
 class _Container(object):
